==> AsposeCellsCloud-CellsApi-25.11.tar.gz: AsposeCellsCloud-CellsApi-25.11/docs/model/ErrorBar.md <==
# AsposeCellsCloud::Object::ErrorBar 

## Load the model package
```perl
use AsposeCellsCloud::Object::ErrorBar;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**Link** | **Link** | A property named "Link" of type "Link" that can be accessed and modified. |
**Amount** | **double** | Represents amount of error bar.                         The amount must be greater than or equal to zero. |
**DisplayType** | **string** | Represents error bar display type. |
**MinusValue** | **string** | Represents negative error amount when error bar type is Custom. |
**PlusValue** | **string** | Represents positive error amount when error bar type is Custom. |
**ShowMarkerTTop** | **boolean** | Indicates if formatting error bars with a T-top. |
**Type** | **string** | Represents error bar amount type. |
**BeginArrowLength** | **string** |  |
**BeginArrowWidth** | **string** |  |
**BeginType** | **string** |  |
**CapType** | **string** |  |
**Color** | **Color** |  |
**CompoundType** | **string** |  |
**DashType** | **string** |  |
**EndArrowLength** | **string** |  |
**EndArrowWidth** | **string** |  |
**EndType** | **string** |  |
**GradientFill** | **GradientFill** |  |
**IsAuto** | **boolean** |  |
**IsAutomaticColor** | **boolean** |  |
**IsVisible** | **boolean** |  |
**JoinType** | **string** |  |
**Style** | **string** |  |
**Transparency** | **double** |  |
**Weight** | **string** |  |
**WeightPt** | **double** |  |  

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

==> AsposeCellsCloud-CellsApi-26.2.tar.gz: AsposeCellsCloud-CellsApi-26.2/docs/model/ErrorBar.md <==
# AsposeCellsCloud::Object::ErrorBar 

## Load the model package
```perl
use AsposeCellsCloud::Object::ErrorBar;
```

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**Link** | **Link** | A property named "Link" of type "Link" that can be accessed and modified. |
**Amount** | **double** | Represents amount of error bar.                         The amount must be greater than or equal to zero. |
**DisplayType** | **string** | Represents error bar display type. |
**MinusValue** | **string** | Represents negative error amount when error bar type is Custom. |
**PlusValue** | **string** | Represents positive error amount when error bar type is Custom. |
**ShowMarkerTTop** | **boolean** | Indicates if formatting error bars with a T-top. |
**Type** | **string** | Represents error bar amount type. |
**BeginArrowLength** | **string** |  |
**BeginArrowWidth** | **string** |  |
**BeginType** | **string** |  |
**CapType** | **string** |  |
**Color** | **Color** |  |
**CompoundType** | **string** |  |
**DashType** | **string** |  |
**EndArrowLength** | **string** |  |
**EndArrowWidth** | **string** |  |
**EndType** | **string** |  |
**GradientFill** | **GradientFill** |  |
**IsAuto** | **boolean** |  |
**IsAutomaticColor** | **boolean** |  |
**IsVisible** | **boolean** |  |
**JoinType** | **string** |  |
**Style** | **string** |  |
**Transparency** | **double** |  |
**Weight** | **string** |  |
**WeightPt** | **double** |  |  


[[Back to Model list]](../DeveloperGuide.md#model-reference)  
[[Back to README]](../../README.md)
